"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreset = void 0;
const npmrc_1 = require("../../../datasource/npm/npmrc");
const logger_1 = require("../../../logger");
const http_1 = require("../../../util/http");
const id = 'npm';
const http = new http_1.Http(id);
async function getPreset({ packageName, presetName = 'default', }) {
    let dep;
    try {
        const { headers, packageUrl } = npmrc_1.resolvePackage(packageName);
        const body = (await http.getJson(packageUrl, { headers }))
            .body;
        dep = body.versions[body['dist-tags'].latest];
    }
    catch (err) {
        throw new Error('dep not found');
    }
    if (!dep['renovate-config']) {
        throw new Error('preset renovate-config not found');
    }
    const presetConfig = dep['renovate-config'][presetName];
    if (!presetConfig) {
        const presetNames = Object.keys(dep['renovate-config']);
        logger_1.logger.debug({ presetNames, presetName }, 'Preset not found within renovate-config');
        throw new Error('preset not found');
    }
    return presetConfig;
}
exports.getPreset = getPreset;
//# sourceMappingURL=index.js.map